# Kante

Kante is a simple lightweight strawberry utily library, that
merges the efforts of 

-   [authentikate](https://github.com/jhnnsrs/authentikate)

    For Token based authentication

-   [koherent](https://github.com/jhnnsrs/koherent)

    For a simple ASSIGNATION_ID based audit trail
